@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2010 NICTA (www.nicta.com.au)
-// Copyright (C) 2008-2010 Conrad Sanderson
+// Copyright (C) 2008-2011 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2011 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -23,6 +23,12 @@ class op_min
   template<typename eT>
   inline static eT direct_min(const eT* const X, const u32 N);
   
+  template<typename eT>
+  inline static eT direct_min(const eT* const X, const u32 N, u32& index_of_min_val);
+  
+  template<typename eT>
+  inline static eT direct_min(const Mat<eT>& X, const u32 row);
+  
   template<typename eT>
   inline static eT direct_min(const subview<eT>& X);
   
@@ -39,15 +45,18 @@ class op_min
   template<typename T>
   inline static std::complex<T> direct_min(const std::complex<T>* const X, const u32 n_elem);
   
+  template<typename T>
+  inline static std::complex<T> direct_min(const std::complex<T>* const X, const u32 n_elem, u32& index_of_min_val);
+  
+  template<typename T>
+  inline static std::complex<T> direct_min(const Mat< std::complex<T> >& X, const u32 row);
+  
   template<typename T>
   inline static std::complex<T> direct_min(const subview< std::complex<T> >&X);
   
   template<typename T>
   inline static std::complex<T> direct_min(const diagview< std::complex<T> >&X);
   
-  template<typename T, typename T1>
-  inline static void apply(Mat< std::complex<T> >& out, const Op<T1,op_min>& in);
-  
   };
 
 //! @}
